@@ -18,6 +18,7 @@ SEARCHPATH = (
 
 
 class ConfigFinder:
+
     def __init__(self, searchpath=SEARCHPATH):
         self.searchpath = searchpath
 
@@ -37,10 +38,12 @@ class ConfigFinder:
             else:
                 failed.append(path)
 
-        raise RuntimeError("Didn't find a config file, tried\n * {mods}".format(mods="\n * ".join(failed)))
+        raise RuntimeError(
+            "Didn't find a config file, tried\n * {mods}".format(mods="\n * ".join(failed)))
 
 
 class Config:
+
     def __init__(self, config_file=None):
         self.finder = ConfigFinder()
         self.config_file = config_file or self.finder.find_config_file()
@@ -52,12 +55,15 @@ class Config:
         @contextlib.contextmanager
         def setup():
             import i3pystatus
+
             class TestStatus(i3pystatus.Status):
+
                 def run(self):
                     self.modules.reverse()
                     self.call_start_hooks()
                     for module in self.modules:
-                        sys.stdout.write("{module}: ".format(module=module.__name__))
+                        sys.stdout.write(
+                            "{module}: ".format(module=module.__name__))
                         sys.stdout.flush()
                         test = module.test()
                         if test is not True:
@@ -72,5 +78,6 @@ class Config:
             i3pystatus.Status = i3pystatus.Status.__bases__[0]
 
         with setup():
-            print("Using configuration file {file}\n".format(file=self.config_file))
+            print(
+                "Using configuration file {file}\n".format(file=self.config_file))
             self.run()
