@@ -4,7 +4,9 @@ import sys
 import json
 import time
 import threading
-import urllib.request, urllib.parse, urllib.error
+import urllib.request
+import urllib.parse
+import urllib.error
 import re
 import http.cookiejar
 import xml.etree.ElementTree as ET
@@ -12,14 +14,17 @@ import webbrowser
 
 from i3pystatus import IntervalModule
 
+
 class ModsDeChecker(IntervalModule):
+
     """ 
     This class returns i3status parsable output of the number of
     unread posts in any bookmark in the mods.de forums.
     """
 
     settings = (
-        ("format", """Use {unread} as the formatter for number of unread posts"""),
+        ("format",
+         """Use {unread} as the formatter for number of unread posts"""),
         ("offset", """subtract number of posts before output"""),
         "color", "username", "password"
     )
@@ -37,7 +42,8 @@ class ModsDeChecker(IntervalModule):
 
     def init(self):
         self.cj = http.cookiejar.CookieJar()
-        self.opener = urllib.request.build_opener(urllib.request.HTTPCookieProcessor(self.cj))
+        self.opener = urllib.request.build_opener(
+            urllib.request.HTTPCookieProcessor(self.cj))
 
     def run(self):
         unread = self.get_unread_count()
@@ -46,9 +52,9 @@ class ModsDeChecker(IntervalModule):
             self.output = None
         else:
             self.output = {
-                "full_text" : self.format.format(unread=unread),
-                "urgent" : "true",
-                "color" : self.color
+                "full_text": self.format.format(unread=unread),
+                "urgent": "true",
+                "color": self.color
             }
 
     def get_unread_count(self):
@@ -61,7 +67,8 @@ class ModsDeChecker(IntervalModule):
             return int(root.attrib["newposts"]) - self.offset
         except Exception:
             self.cj.clear()
-            self.opener = urllib.request.build_opener(urllib.request.HTTPCookieProcessor(self.cj))
+            self.opener = urllib.request.build_opener(
+                urllib.request.HTTPCookieProcessor(self.cj))
             self.logged_in = False
 
     def test(self):
@@ -92,7 +99,8 @@ class ModsDeChecker(IntervalModule):
             for cookie in self.cj:
                 self.cj.clear
                 self.logged_in = True
-                self.opener.addheaders.append(("Cookie", "{}={}".format(cookie.name, cookie.value)))
+                self.opener.addheaders.append(
+                    ("Cookie", "{}={}".format(cookie.name, cookie.value)))
             return True
         return False
 
