@@ -7,15 +7,18 @@ from lxml.cssselect import CSSSelector
 
 from i3pystatus import IntervalModule
 
+
 class TrackerAPI:
+
     def __init__(self, idcode):
         pass
 
     def status(self):
         return {}
 
+
 class DHL(TrackerAPI):
-    URL="http://nolp.dhl.de/nextt-online-public/set_identcodes.do?lang=en&idc={idcode}"
+    URL = "http://nolp.dhl.de/nextt-online-public/set_identcodes.do?lang=en&idc={idcode}"
 
     def __init__(self, idcode):
         self.idcode = idcode
@@ -23,7 +26,8 @@ class DHL(TrackerAPI):
 
         error_selector = CSSSelector("#set_identcodes .error")
         self.error = lambda page: len(error_selector(page)) >= 1
-        self.progress_selector = CSSSelector(".greyprogressbar > span, .greenprogressbar > span")
+        self.progress_selector = CSSSelector(
+            ".greyprogressbar > span, .greenprogressbar > span")
         self.last_status_selector = CSSSelector(".events .eventList tr")
         self.intrarow_status_selector = CSSSelector("td.status div")
 
@@ -36,14 +40,16 @@ class DHL(TrackerAPI):
             else:
                 ret["progress"] = self.progress_selector(page)[0].text.strip()
                 last_row = self.last_status_selector(page)[-1]
-                ret["status"] = self.intrarow_status_selector(last_row)[0].text.strip()
+                ret["status"] = self.intrarow_status_selector(
+                    last_row)[0].text.strip()
         return ret
 
     def get_url(self):
         return self.url
 
+
 class UPS(TrackerAPI):
-    URL="http://wwwapps.ups.com/WebTracking/processRequest?HTMLVersion=5.0&Requester=NES&AgreeToTermsAndConditions=yes&loc=en_US&tracknum={idcode}"
+    URL = "http://wwwapps.ups.com/WebTracking/processRequest?HTMLVersion=5.0&Requester=NES&AgreeToTermsAndConditions=yes&loc=en_US&tracknum={idcode}"
 
     def __init__(self, idcode):
         self.idcode = idcode
@@ -62,13 +68,15 @@ class UPS(TrackerAPI):
                 ret["progress"] = ret["status"] = "n/a"
             else:
                 ret["status"] = self.status_selector(page)[0].text.strip()
-                progress_cls = int(int(self.progress_selector(page)[0].get("class").strip("staus")) / 5 * 100)
-                ret["progress"]  = progress_cls
+                progress_cls = int(
+                    int(self.progress_selector(page)[0].get("class").strip("staus")) / 5 * 100)
+                ret["progress"] = progress_cls
         return ret
 
     def get_url(self):
         return self.url
 
+
 class ParcelTracker(IntervalModule):
     interval = 20
 
