@@ -2,7 +2,9 @@ from .pulse import *
 
 from i3pystatus import Module
 
+
 class PulseAudio(Module):
+
     """
     Shows volume of default PulseAudio sink (output).
 
@@ -22,10 +24,11 @@ class PulseAudio(Module):
         """Creates context, when context is ready context_notify_cb is called"""
         # Wrap callback methods in appropriate ctypefunc instances so
         # that the Pulseaudio C API can call them
-        self._context_notify_cb = pa_context_notify_cb_t(self.context_notify_cb)
+        self._context_notify_cb = pa_context_notify_cb_t(
+            self.context_notify_cb)
         self._sink_info_cb = pa_sink_info_cb_t(self.sink_info_cb)
         self._update_cb = pa_context_subscribe_cb_t(self.update_cb)
-        self._success_cb = pa_context_success_cb_t (self.success_cb)
+        self._success_cb = pa_context_success_cb_t(self.success_cb)
         self._server_info_cb = pa_server_info_cb_t(self.server_info_cb)
 
         # Create the mainloop thread and set our context_notify_cb
@@ -41,7 +44,8 @@ class PulseAudio(Module):
 
     def request_update(self, context):
         """Requests a sink info update (sink_info_cb is called)"""
-        pa_operation_unref(pa_context_get_sink_info_by_name(context, self.sink, self._sink_info_cb, None))
+        pa_operation_unref(pa_context_get_sink_info_by_name(
+            context, self.sink, self._sink_info_cb, None))
 
     def success_cb(self, context, success, userdata):
         pass
@@ -63,11 +67,13 @@ class PulseAudio(Module):
         state = pa_context_get_state(context)
 
         if state == PA_CONTEXT_READY:
-            pa_operation_unref(pa_context_get_server_info(context, self._server_info_cb, None))
+            pa_operation_unref(
+                pa_context_get_server_info(context, self._server_info_cb, None))
 
             pa_context_set_subscribe_callback(context, self._update_cb, None)
 
-            pa_operation_unref(pa_context_subscribe(context, PA_SUBSCRIPTION_EVENT_CHANGE|PA_SUBSCRIPTION_MASK_SINK, self._success_cb, None))
+            pa_operation_unref(pa_context_subscribe(
+                context, PA_SUBSCRIPTION_EVENT_CHANGE | PA_SUBSCRIPTION_MASK_SINK, self._success_cb, None))
 
     def update_cb(self, context, t, idx, userdata):
         """A sink property changed, calls request_update"""
@@ -77,7 +83,7 @@ class PulseAudio(Module):
         """Updates self.output"""
         if sink_info_p:
             sink_info = sink_info_p.contents
-            volume_percent = int(100 * sink_info.volume.values[0]/0x10000)
+            volume_percent = int(100 * sink_info.volume.values[0] / 0x10000)
             volume_db = pa_sw_volume_to_dB(sink_info.volume.values[0])
             if volume_db == float('-Infinity'):
                 volume_db = "-∞"
